@@ -228,7 +228,11 @@ BOOL filer_vd_end(int dir)
     sDir* self = (sDir*)vector_item(gDirs, dir);
 
     self->mVD = FALSE;
-    return filer_reread(dir);
+
+    char buf[256];
+    snprintf(buf, 256, "reread -d %d", dir);
+    int rcode;
+    return xyzsh_eval(&rcode, buf, "reread", NULL, gStdin, gStdout, 0, NULL, gMFiler4);
 }
 
 BOOL filer_vd_add(int dir, char* fname)
@@ -352,6 +356,24 @@ BOOL filer_add_history(int dir, char* path)
     return TRUE;
 }
 
+// result --> vector_obj of string_obj
+BOOL filer_get_hitory(sObject* result, int dir)
+{
+    ASSERT(TYPE(result) == T_VECTOR);
+
+    if(dir < 0 || dir >= vector_count(gDirs)) {
+        return FALSE;
+    }
+    sDir* dir2 = (sDir*)vector_item(gDirs, dir);
+
+    int i;
+    for(i=1; i<=dir2->mHistoryCursor; i++) {
+        vector_add(result, vector_item(dir2->mHistory, i));
+    }
+
+    return TRUE;
+}
+
 static int correct_path(char* current_path, char* path, char* path2, int path2_size)
 {
     char tmp[PATH_MAX];
@@ -885,9 +907,13 @@ void filer_input(int meta, int key)
                 if(rcode == 0) {
                     xinitscr();
 
-                    filer_reread(0);
-                    filer_reread(1);
-                    (void)filer_reset_marks(adir());
+                    char buf[256];
+                    snprintf(buf, 256, "reread -d 0; reread -d 1; mark -a 0");
+                    int rcode;
+                    (void)xyzsh_eval(&rcode, buf, "reread", NULL, gStdin, gStdout, 0, NULL, gMFiler4);
+                    //filer_reread(0);
+                    //filer_reread(1);
+                    //(void)filer_reset_marks(adir());
                 }
                 else {
                     char str[128];
@@ -896,7 +922,6 @@ void filer_input(int meta, int key)
                     printf("\nHIT ANY KEY\n");
 
                     xinitscr();
-
                     (void)getch();
                 }
             }
@@ -906,7 +931,6 @@ void filer_input(int meta, int key)
                 printf("\nHIT ANY KEY\n");
 
                 xinitscr();
-
                 (void)getch();
             }
         }
@@ -1438,7 +1462,7 @@ static void make_file_stat(sFile* file, char* buf, int buf_size)
 
     char* env_nlink = getenv("VIEW_NLINK");
     if(env_nlink && strcmp(env_nlink, "1") == 0) {
-        snprintf(buf + strlen(buf), buf_size -strlen(buf), " %3d", file->mStat.st_nlink);
+        snprintf(buf + strlen(buf), buf_size -strlen(buf), " "FORMAT_HARDLINK, file->mStat.st_nlink);
     }
 
     char* env_owner = getenv("VIEW_OWNER");
@@ -1469,6 +1493,20 @@ static void make_file_stat(sFile* file, char* buf, int buf_size)
         snprintf(buf + strlen(buf), buf_size - strlen(buf), " %-8s", group);
     }
 
+    char* env_mtime = getenv("VIEW_MTIME");
+    if(env_mtime && strcmp(env_mtime, "1") == 0) {
+        time_t t = file->mLStat.st_mtime;
+        struct tm* tm_ = (struct tm*)localtime(&t);
+
+        int year = tm_->tm_year-100;
+        if(year < 0) year+=100;
+        while(year > 100) year-=100;
+
+        snprintf(buf + strlen(buf), buf_size - strlen(buf), " %02d-%02d-%02d %02d:%02d"
+               , year, tm_->tm_mon+1
+               , tm_->tm_mday, tm_->tm_hour, tm_->tm_min);
+    }
+
     char* env_size = getenv("VIEW_SIZE");
     if(env_size && strcmp(env_size, "1") == 0) {
         char size[256];
@@ -1486,20 +1524,6 @@ static void make_file_stat(sFile* file, char* buf, int buf_size)
         snprintf(buf + strlen(buf), 256, format, size);
     }
 
-    char* env_mtime = getenv("VIEW_MTIME");
-    if(env_mtime && strcmp(env_mtime, "1") == 0) {
-        time_t t = file->mLStat.st_mtime;
-        struct tm* tm_ = (struct tm*)localtime(&t);
-
-        int year = tm_->tm_year-100;
-        if(year < 0) year+=100;
-        while(year > 100) year-=100;
-
-        snprintf(buf + strlen(buf), buf_size - strlen(buf), " %02d-%02d-%02d %02d:%02d"
-               , year, tm_->tm_mon+1
-               , tm_->tm_mday, tm_->tm_hour, tm_->tm_min);
-    }
-
     snprintf(buf + strlen(buf), buf_size - strlen(buf), " ");
 }
 
@@ -1644,25 +1668,25 @@ void filer_view(int dir)
     char* env_color_dir = getenv("COLOR_DIR");
     int color_dir = 0;
     if(env_color_dir) {
-        color_dir = atoi(env_color_dir) | A_BOLD;
+        color_dir = atoi(env_color_dir);
     }
 
     char* env_color_exe = getenv("COLOR_EXE");
     int color_exe = 0;
     if(env_color_exe) {
-        color_exe = atoi(env_color_exe)| A_BOLD;
+        color_exe = atoi(env_color_exe);
     }
 
     char* env_color_link = getenv("COLOR_LINK");
     int color_link = 0;
     if(env_color_link) {
-        color_link = atoi(env_color_link)| A_BOLD;
+        color_link = atoi(env_color_link);
     }
 
     char* env_color_mark = getenv("COLOR_MARK");
     int color_mark = 0;
     if(env_color_mark) {
-        color_mark = atoi(env_color_mark)| A_BOLD;
+        color_mark = atoi(env_color_mark);
     }
 
     const int maxx = mgetmaxx();
@@ -2518,7 +2542,8 @@ void cmdline_view_filer()
         while(year > 100) year-=100;
         
         snprintf(buf2, 1024, 
-            "%s %3d %-8s %-7s%s %02d-%02d-%02d %02d:%02d %s"
+            "%s "FORMAT_HARDLINK" %-8s %-7s%s %02d-%02d-%02d %02d:%02d %s"
+            //"%s %3d %-8s %-7s%s %02d-%02d-%02d %02d:%02d %s"
             //, "%s %3d %-8s %-7s%10lld %02d-%02d-%02d %02d:%02d %s"
             , permission, file->mLStat.st_nlink
             , owner, group
@@ -2536,7 +2561,8 @@ void cmdline_view_filer()
     }
     else {
         snprintf(buf, 1024,
-           "%s %3d %s%s%s %02d-%02d-%02d %02d:%02d %s -> %s"
+           "%s "FORMAT_HARDLINK" %s%s%s %02d-%02d-%02d %02d:%02d %s -> %s"
+           //"%s %3d %s%s%s %02d-%02d-%02d %02d:%02d %s -> %s"
            //, "%s %3d %s%s%10lld %02d-%02d-%02d %02d:%02d %s -> %s"
            , permission, file->mLStat.st_nlink
            , owner, group
